@@ -80,7 +80,7 @@ class DTblDef extends DTblDefBase
 				self::NewCustFlagAttr('user', null, (DAttr::BM_HIDE | DAttr::BM_NOEDIT), false),
 				self::NewCustFlagAttr('group', null, (DAttr::BM_HIDE | DAttr::BM_NOEDIT), false),
 				$this->_attrs['priority']->dup(null, null, 'serverPriority'),
-				DTblDefBase::NewIntAttr('cpuAffinity', DMsg::ALbl('l_cpuaffinity'), true, 1),
+				DTblDefBase::NewIntAttr('cpuAffinity', DMsg::ALbl('l_cpuaffinity'), true, 0, 64),
 				DTblDefBase::NewSelAttr( 'enableLVE', DMsg::ALbl('l_enablelve'),
 						array( 0=>DMsg::ALbl('o_disabled'), 1=>"LVE", 2=>"CageFS", 3=>DMsg::ALbl('o_cagefswithoutsuexec') ) ),
 				self::NewIntAttr('inMemBufSize', DMsg::ALbl('l_inmembufsize'), false, 0),
@@ -98,17 +98,27 @@ class DTblDef extends DTblDefBase
 		$attr_mime = self::NewPathAttr('mime', DMsg::ALbl('l_mimesettings'), 'file', 2, 'rw', false);
 		$attr_mime->_href = '&t=S_MIME_TOP';
 
-		$attrs = array(
-				$attr_mime,
-				self::NewBoolAttr('disableInitLogRotation', DMsg::ALbl('l_disableinitlogrotation')),
-				self::NewSelAttr('showVersionNumber', DMsg::ALbl('l_serversig'),
-						array('0'=>DMsg::ALbl('o_hidever'), '1'=>DMsg::ALbl('o_showver'), '2'=>DMsg::ALbl('o_hidefullheader')), false),
-				$this->_attrs['enableIpGeo'],
-				self::NewSelAttr('useIpInProxyHeader', DMsg::ALbl('l_useipinproxyheader'),
-						array('0'=>DMsg::ALbl('o_no'), '1'=>DMsg::ALbl('o_yes'),
-                            '2'=>DMsg::ALbl('o_trustediponly'), '3' =>DMsg::ALbl('o_keepheaderfortrusted')) ),
-				$this->_attrs['adminEmails'],
-		);
+		$attrs = [
+            $attr_mime,
+            self::NewBoolAttr('disableInitLogRotation', DMsg::ALbl('l_disableinitlogrotation')),
+            self::NewSelAttr('showVersionNumber', DMsg::ALbl('l_serversig'),
+                    [
+                        '0' => DMsg::ALbl('o_hidever'),
+                        '1' => DMsg::ALbl('o_showver'),
+                        '2' => DMsg::ALbl('o_hidefullheader'),
+                    ], false),
+            $this->_attrs['enableIpGeo'],
+            self::NewSelAttr('useIpInProxyHeader', DMsg::ALbl('l_useipinproxyheader'),
+                    [
+                        '0' => DMsg::ALbl('o_no'),
+                        '1' => DMsg::ALbl('o_yes'),
+                        '2' => DMsg::ALbl('o_trustediponly'),
+                        '3' => DMsg::ALbl('o_keepheaderfortrusted'),
+                        '4' => DMsg::ALbl('o_use_last_ip_for elb'),
+            ]),
+            $this->_attrs['adminEmails'],
+        ];        
+        
 		$this->_tblDef[$id] = DTbl::NewRegular($id, DMsg::ALbl('l_generalsettings'), $attrs);
 	}
 
@@ -267,7 +277,7 @@ class DTblDef extends DTblDefBase
 		$align = array('center', 'center', 'center', 'center');
 
 		$attrs = array(self::NewViewAttr('name', DMsg::ALbl('l_module')),
-				//self::NewBoolAttr('internal', DMsg::ALbl('l_internal'), true, 'internalmodule'),
+				self::NewBoolAttr('internal', DMsg::ALbl('l_internal'), true, 'internalmodule'),
 				$this->_attrs['mod_params'],
 				$this->_attrs['mod_enabled'],
 				self::NewActionAttr('S_MOD', 'vEd')
@@ -289,7 +299,7 @@ class DTblDef extends DTblDefBase
 	{
 		$attrs = array(self::NewTextAttr('name', DMsg::ALbl('l_module'), 'modulename', false, 'modulename'),
 						$this->_attrs['note'],
-						//self::NewBoolAttr('internal', DMsg::ALbl('l_internal'), true, 'internalmodule'),
+						self::NewBoolAttr('internal', DMsg::ALbl('l_internal'), true, 'internalmodule'),
 						$this->_attrs['mod_params'],
 						$this->_attrs['mod_enabled']);
 
@@ -383,7 +393,6 @@ class DTblDef extends DTblDefBase
 			$this->_attrs['vh_enableScript'],
 			$this->_attrs['vh_restrained'],
 			$this->_attrs['vh_maxKeepAliveReq'],
-			$this->_attrs['vh_smartKeepAlive'],
 			$this->_attrs['vh_setUIDMode'],
             $this->_attrs['vh_suexec_user'],
             $this->_attrs['vh_suexec_group'],
@@ -448,7 +457,6 @@ class DTblDef extends DTblDefBase
     {
         $attrs = array(
             $this->_attrs['vh_maxKeepAliveReq'],
-            $this->_attrs['vh_smartKeepAlive']
         );
         $this->_tblDef[$id] = DTbl::NewRegular($id, DMsg::ALbl('l_connection'), $attrs);
     }
@@ -697,14 +705,16 @@ class DTblDef extends DTblDefBase
 		$port->SetFlag(DAttr::BM_NOFILE);
 
 		$processes = isset($_SERVER['LSWS_CHILDREN']) ? $_SERVER['LSWS_CHILDREN'] : 1;
-		for( $i = 1; $i <= $processes; ++$i )
+		for( $i = 1; $i <= $processes; ++$i ) {
 			$bindoptions[1<<($i-1)] = "Process $i";
+        }
 
 		$attrs = array(
 				self::NewTextAttr('name', DMsg::ALbl('l_listenername'), 'name', false, 'listenerName'),
 				self::NewCustFlagAttr('address', DMsg::ALbl('l_address'), (DAttr::BM_HIDE | DAttr::BM_NOEDIT), false),
 				$ip, $port,
 				self::NewCheckBoxAttr('binding', DMsg::ALbl('l_binding'), $bindoptions, true, 'listenerBinding'),
+                self::NewBoolAttr('reusePort', DMsg::ALbl('l_reuseport')),
 				self::NewBoolAttr('secure', DMsg::ALbl('l_secure'), false, 'listenerSecure'),
 				$this->_attrs['note'],
 		);
